@@ -44,7 +44,7 @@ extern zend_module_entry yaf_module_entry;
 # define ZEND_ACC_DTOR	0x0
 #endif
 
-#define PHP_YAF_VERSION 					"3.2.4"
+#define PHP_YAF_VERSION 					"3.2.5"
 
 #define YAF_STARTUP_FUNCTION(module)   	ZEND_MINIT_FUNCTION(yaf_##module)
 #define YAF_RINIT_FUNCTION(module)		ZEND_RINIT_FUNCTION(yaf_##module)
@@ -54,16 +54,22 @@ extern zend_module_entry yaf_module_entry;
 #define YAF_ME(c, m, a, f)              {m, PHP_MN(c), a, (unsigned)(sizeof(a)/sizeof(struct _zend_arg_info)-1), f},
 #define YAF_VAR_FLAGS(v)                ((v).u2.next)
 
+#if PHP_VERSION_ID < 70200
+#define YAF_ALLOW_VIOLATION(ht)
+#else
+#define YAF_ALLOW_VIOLATION(ht) do { \
+	zend_hash_real_init(ht, 0);      \
+	HT_ALLOW_COW_VIOLATION(ht);      \
+} while (0)
+#endif
+
 #if PHP_VERSION_ID < 70400
 #define YAF_WRITE_HANDLER       void
 #define YAF_WHANDLER_RET(zv)    return
-#ifndef HT_ALLOW_COW_VIOLATION
-# define HT_ALLOW_COW_VIOLATION(ht)
-#endif
-#if PHP_VERSION_ID < 70300
+# if PHP_VERSION_ID < 70300
 # define GC_ADDREF(gc)           (++GC_REFCOUNT(gc))
 # define GC_DELREF(gc)           (--GC_REFCOUNT(gc))
-#endif
+# endif
 #else
 #define YAF_WRITE_HANDLER       zval *
 #define YAF_WHANDLER_RET(zv)    return zv
