@@ -50,7 +50,7 @@ static HashTable *yaf_route_map_get_properties(zval *object) /* {{{ */ {
 	if (!map->properties) {
 		ALLOC_HASHTABLE(map->properties);
 		zend_hash_init(map->properties, 2, NULL, ZVAL_PTR_DTOR, 0);
-		HT_ALLOW_COW_VIOLATION(map->properties);
+		YAF_ALLOW_VIOLATION(map->properties);
 
 		ht = map->properties;
 
