@@ -143,7 +143,7 @@ static HashTable *yaf_dispatcher_get_properties(zval *object) /* {{{ */ {
 	if (!dispatcher->properties) {
 		ALLOC_HASHTABLE(dispatcher->properties);
 		zend_hash_init(dispatcher->properties, 16, NULL, ZVAL_PTR_DTOR, 0);
-		HT_ALLOW_COW_VIOLATION(dispatcher->properties);
+		YAF_ALLOW_VIOLATION(dispatcher->properties);
 	}
 
 	ht = dispatcher->properties;
@@ -790,6 +790,8 @@ ZEND_HOT yaf_response_t *yaf_dispatcher_dispatch(yaf_dispatcher_object *dispatch
 	}
 
 	do {
+		/* plugins maybe added in controller? */
+		plugins = dispatcher->plugins;
 		YAF_PLUGIN_HANDLE(dispatcher, plugins, YAF_PLUGIN_HOOK_PREDISPATCH);
 		if (UNEXPECTED(!yaf_dispatcher_handle(dispatcher))) {
 			YAF_EXCEPTION_HANDLE_NORET(dispatcher);
