@@ -163,7 +163,6 @@ static zend_array *yaf_loader_get_namespaces(yaf_loader_object *loader) /* {{{ *
 
 	ALLOC_HASHTABLE(ht);
 	zend_hash_init(ht, zend_hash_num_elements(YAF_LOADER_NAMESPACES(loader)), NULL, ZVAL_PTR_DTOR, 0);
-	HT_ALLOW_COW_VIOLATION(YAF_LOADER_NAMESPACES(loader));
 
 	ZEND_HASH_FOREACH_STR_KEY_VAL(YAF_LOADER_NAMESPACES(loader), name, val) {
 		ZEND_ASSERT(name);
@@ -188,7 +187,7 @@ static HashTable *yaf_loader_get_properties(zval *object) /* {{{ */ {
 	if (!loader->properties) {
 		ALLOC_HASHTABLE(loader->properties);
 		zend_hash_init(loader->properties, 4, NULL, ZVAL_PTR_DTOR, 0);
-		HT_ALLOW_COW_VIOLATION(loader->properties);;
+		YAF_ALLOW_VIOLATION(loader->properties);;
 	}
 
 	ht = loader->properties;
@@ -260,7 +259,7 @@ yaf_loader_t *yaf_loader_instance(zend_string *library_path) /* {{{ */ {
 	
 	ALLOC_HASHTABLE(YAF_LOADER_NAMESPACES(loader));
 	zend_hash_init(YAF_LOADER_NAMESPACES(loader), 8, NULL, ZVAL_PTR_DTOR, 0);
-	HT_ALLOW_COW_VIOLATION(YAF_LOADER_NAMESPACES(loader));
+	YAF_ALLOW_VIOLATION(YAF_LOADER_NAMESPACES(loader));
 
 	loader->properties = NULL;
 
