@@ -163,7 +163,7 @@ static HashTable *yaf_request_get_properties(zval *object) /* {{{ */ {
 	if (!request->properties) {
 		ALLOC_HASHTABLE(request->properties);
 		zend_hash_init(request->properties, 16, NULL, ZVAL_PTR_DTOR, 0);
-		HT_ALLOW_COW_VIOLATION(request->properties);
+		YAF_ALLOW_VIOLATION(request->properties);
 	}
 
 	ht = request->properties;
@@ -634,7 +634,7 @@ void yaf_request_set_mvc(yaf_request_object *request, zend_string *module, zend_
 		if (!request->params) {
 			ALLOC_HASHTABLE(request->params);
 			zend_hash_init(request->params, zend_hash_num_elements(params), NULL, ZVAL_PTR_DTOR, 0);
-			HT_ALLOW_COW_VIOLATION(request->params);
+			YAF_ALLOW_VIOLATION(request->params);
 		}
 		zend_hash_copy(request->params, params, (copy_ctor_func_t) zval_add_ref);
 	}
@@ -739,7 +739,7 @@ int yaf_request_set_params_single(yaf_request_object *request, zend_string *key,
 	if (!request->params) {
 		ALLOC_HASHTABLE(request->params);
 		zend_hash_init(request->params, 8, NULL, ZVAL_PTR_DTOR, 0);
-		HT_ALLOW_COW_VIOLATION(request->params);
+		YAF_ALLOW_VIOLATION(request->params);
 	}
 	if ((zend_hash_update(request->params, key, value)) != NULL) {
 		Z_TRY_ADDREF_P(value);
@@ -1027,12 +1027,14 @@ PHP_METHOD(yaf_request, setModuleName) {
 		return;
 	}
 
-	if (format_name) {
-		yaf_request_set_module(request, module);
-	} else {
-		if (request->module) {
-			zend_string_release(request->module);
-			request->module = zend_string_copy(module);
+	if (EXPECTED(ZSTR_LEN(module))) {
+		if (format_name) {
+			yaf_request_set_module(request, module);
+		} else {
+			if (request->module) {
+				zend_string_release(request->module);
+				request->module = zend_string_copy(module);
+			}
 		}
 	}
 
@@ -1051,12 +1053,14 @@ PHP_METHOD(yaf_request, setControllerName) {
 		return;
 	}
 
-	if (format_name) {
-		yaf_request_set_controller(request, controller);
-	} else {
-		if (request->controller) {
-			zend_string_release(request->controller);
-			request->controller = zend_string_copy(controller);
+	if (EXPECTED(ZSTR_LEN(controller))) {
+		if (format_name) {
+			yaf_request_set_controller(request, controller);
+		} else {
+			if (request->controller) {
+				zend_string_release(request->controller);
+				request->controller = zend_string_copy(controller);
+			}
 		}
 	}
 
@@ -1075,12 +1079,14 @@ PHP_METHOD(yaf_request, setActionName) {
 		return;
 	}
 
-	if (format_name) {
-		yaf_request_set_action(request, action);
-	} else {
-		if (request->action) {
-			zend_string_release(request->action);
-			request->action = zend_string_copy(action);
+	if (EXPECTED(ZSTR_LEN(action))) {
+		if (format_name) {
+			yaf_request_set_action(request, action);
+		} else {
+			if (request->action) {
+				zend_string_release(request->action);
+				request->action = zend_string_copy(action);
+			}
 		}
 	}
 
